==> okta-sdk-api-21.0.0-sources.jar: com/okta/sdk/resource/model/SAMLPayLoadDataAssertionClaimsValueAttributeValuesInnerAttributes.java <==
package com.okta.sdk.resource.model;

import java.util.Objects;
import java.util.Arrays;
import com.fasterxml.jackson.annotation.JsonInclude;
import com.fasterxml.jackson.annotation.JsonProperty;
import com.fasterxml.jackson.annotation.JsonCreator;
import com.fasterxml.jackson.annotation.JsonTypeName;
import com.fasterxml.jackson.annotation.JsonValue;
import java.io.Serializable;
import com.fasterxml.jackson.annotation.JsonPropertyOrder;
import com.fasterxml.jackson.annotation.JsonTypeName;
import io.swagger.annotations.ApiModelProperty;
import io.swagger.annotations.ApiModel;

/**
 * SAMLPayLoadDataAssertionClaimsValueAttributeValuesInnerAttributes
 */
@JsonPropertyOrder({ SAMLPayLoadDataAssertionClaimsValueAttributeValuesInnerAttributes.JSON_PROPERTY_XSI_TYPE })
@JsonTypeName("SAMLPayLoad_data_assertion_claims_value_attributeValues_inner_attributes")
@jakarta.annotation.Generated(value = "org.openapitools.codegen.languages.JavaClientCodegen", date = "2025-02-24T22:29:38.763116-06:00[America/Chicago]", comments = "Generator version: 7.11.0")
public class SAMLPayLoadDataAssertionClaimsValueAttributeValuesInnerAttributes implements Serializable {

    private static final long serialVersionUID = 1L;

    public static final String JSON_PROPERTY_XSI_TYPE = "xsi:type";
    private String xsiType;

    public SAMLPayLoadDataAssertionClaimsValueAttributeValuesInnerAttributes() {
    }

    public SAMLPayLoadDataAssertionClaimsValueAttributeValuesInnerAttributes xsiType(String xsiType) {

        this.xsiType = xsiType;
        return this;
    }

    /**
     * Used to derive the type of the attribute
     *
     * @return xsiType
     **/
    @javax.annotation.Nullable
    @ApiModelProperty(value = "Used to derive the type of the attribute")
    @JsonProperty(JSON_PROPERTY_XSI_TYPE)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)

    public String getXsiType() {
        return xsiType;
    }

    @JsonProperty(JSON_PROPERTY_XSI_TYPE)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)
    public void setXsiType(String xsiType) {
        this.xsiType = xsiType;
    }

    @Override
    public boolean equals(Object o) {
        if (this == o) {
            return true;
        }
        if (o == null || getClass() != o.getClass()) {
            return false;
        }
        SAMLPayLoadDataAssertionClaimsValueAttributeValuesInnerAttributes saMLPayLoadDataAssertionClaimsValueAttributeValuesInnerAttributes = (SAMLPayLoadDataAssertionClaimsValueAttributeValuesInnerAttributes) o;
        return Objects.equals(this.xsiType, saMLPayLoadDataAssertionClaimsValueAttributeValuesInnerAttributes.xsiType);
        // ;
    }

    @Override
    public int hashCode() {
        return Objects.hash(xsiType);
    }

    @Override
    public String toString() {
        StringBuilder sb = new StringBuilder();
        sb.append("class SAMLPayLoadDataAssertionClaimsValueAttributeValuesInnerAttributes {\n");
        sb.append("    xsiType: ").append(toIndentedString(xsiType)).append("\n");
        sb.append("}");
        return sb.toString();
    }

    /**
     * Convert the given object to string with each line indented by 4 spaces (except the first line).
     */
    private String toIndentedString(Object o) {
        if (o == null) {
            return "null";
        }
        return o.toString().replace("\n", "\n    ");
    }

}

==> okta-sdk-api-23.0.0-sources.jar: com/okta/sdk/resource/model/SAMLPayLoadDataAssertionClaimsValueAttributeValuesInnerAttributes.java <==
package com.okta.sdk.resource.model;

import java.util.Objects;
import java.util.Arrays;
import com.fasterxml.jackson.annotation.JsonInclude;
import com.fasterxml.jackson.annotation.JsonProperty;
import com.fasterxml.jackson.annotation.JsonCreator;
import com.fasterxml.jackson.annotation.JsonTypeName;
import com.fasterxml.jackson.annotation.JsonValue;
import java.io.Serializable;
import com.fasterxml.jackson.annotation.JsonPropertyOrder;
import com.fasterxml.jackson.annotation.JsonTypeName;
import io.swagger.annotations.ApiModelProperty;
import io.swagger.annotations.ApiModel;

/**
 * SAMLPayLoadDataAssertionClaimsValueAttributeValuesInnerAttributes
 */
@JsonPropertyOrder({ SAMLPayLoadDataAssertionClaimsValueAttributeValuesInnerAttributes.JSON_PROPERTY_XSI_TYPE })
@JsonTypeName("SAMLPayLoad_data_assertion_claims_value_attributeValues_inner_attributes")
@jakarta.annotation.Generated(value = "org.openapitools.codegen.languages.JavaClientCodegen", date = "2025-05-05T16:46:15.395194+05:30[Asia/Kolkata]", comments = "Generator version: 7.11.0")
public class SAMLPayLoadDataAssertionClaimsValueAttributeValuesInnerAttributes implements Serializable {

    private static final long serialVersionUID = 1L;

    public static final String JSON_PROPERTY_XSI_TYPE = "xsi:type";
    private String xsiType;

    public SAMLPayLoadDataAssertionClaimsValueAttributeValuesInnerAttributes() {
    }

    public SAMLPayLoadDataAssertionClaimsValueAttributeValuesInnerAttributes xsiType(String xsiType) {

        this.xsiType = xsiType;
        return this;
    }

    /**
     * Used to derive the type of the attribute
     *
     * @return xsiType
     **/
    @javax.annotation.Nullable
    @ApiModelProperty(value = "Used to derive the type of the attribute")
    @JsonProperty(JSON_PROPERTY_XSI_TYPE)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)

    public String getXsiType() {
        return xsiType;
    }

    @JsonProperty(JSON_PROPERTY_XSI_TYPE)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)
    public void setXsiType(String xsiType) {
        this.xsiType = xsiType;
    }

    @Override
    public boolean equals(Object o) {
        if (this == o) {
            return true;
        }
        if (o == null || getClass() != o.getClass()) {
            return false;
        }
        SAMLPayLoadDataAssertionClaimsValueAttributeValuesInnerAttributes saMLPayLoadDataAssertionClaimsValueAttributeValuesInnerAttributes = (SAMLPayLoadDataAssertionClaimsValueAttributeValuesInnerAttributes) o;
        return Objects.equals(this.xsiType, saMLPayLoadDataAssertionClaimsValueAttributeValuesInnerAttributes.xsiType);
        // ;
    }

    @Override
    public int hashCode() {
        return Objects.hash(xsiType);
    }

    @Override
    public String toString() {
        StringBuilder sb = new StringBuilder();
        sb.append("class SAMLPayLoadDataAssertionClaimsValueAttributeValuesInnerAttributes {\n");
        sb.append("    xsiType: ").append(toIndentedString(xsiType)).append("\n");
        sb.append("}");
        return sb.toString();
    }

    /**
     * Convert the given object to string with each line indented by 4 spaces (except the first line).
     */
    private String toIndentedString(Object o) {
        if (o == null) {
            return "null";
        }
        return o.toString().replace("\n", "\n    ");
    }

}
